@@ -968,16 +968,18 @@ def _extractdatefield(
     compiler: SubstraitCompiler,
     **kwargs: Any,
 ) -> stalg.Expression:
+    # e.g. "ExtractYear" -> "YEAR"
+    span = type(op).__name__[len("Extract") :].upper()
+    args = (
+        translate(arg, compiler, **kwargs)
+        for arg in op.args
+        if isinstance(arg, ir.Expr)
+    )
+
     scalar_func = stalg.Expression.ScalarFunction(
         function_reference=compiler.function_id(expr),
         output_type=translate(expr.type()),
-        args=[
-            translate(arg, compiler, **kwargs)
-            for arg in op.args
-            if isinstance(arg, ir.Expr)
-        ],
     )
-    # e.g. "ExtractYear" -> "YEAR"
-    span = type(op).__name__.lstrip("Extract").upper()
     scalar_func.args.add(enum=stalg.Expression.Enum(specified=span))
+    scalar_func.args.extend(args)
     return stalg.Expression(scalar_function=scalar_func)
